#include "mainwindow.h"
#include "ui_mainwindow.h"

const QString PLANTILLA = "album_art_names=Cover.jpg/cover.jpg/AlbumArtSmall.jpg/albumartsmall.jpg/AlbumArt.jpg/albumart.jpg/Album.jpg/album.jpg/Folder.jpg/folder.jpg/Thumb.jpg/thumb.jpg\nenable_tivo=no\nstrict_dlna=no\nnotify_interval=900\nserial=12345678\nmodel_number=1"; /*!< String value plantilla. Text addicional amb parametres de l'arxiu de configuració que es considera que l'usuari estandar no canviara*/
QString defaultLocation = "/home/"; /*!< Valor de cadena Qt del directori per defecte. Variable auxiliar per als directoris de treball */
QString defaultLocationdB = "/home/"; /*!< Valor de cadena Qt del directori per defecte de la base de dades. Variable auxiliar global per als directoris de treball*/
QString defaultLocationlogs = "/home/";/*!< Valor de cadena Qt del directori per defecte dels arxius logs i de configuració. Variable auxiliar global per als directoris de treball*/
QModelIndex seleccionat;


MainWindow::MainWindow(QWidget *parent) :
    QMainWindow(parent),
    ui(new Ui::MainWindow)
{
    ui->setupUi(this);
    /*Pestanya de configuració per defecte*/
    ui->tabWidget->setCurrentIndex(0);
    /* Introduim les direccions que vilem que ens apareguin per defecte*/
    defaultLocation.append(getenv("USER"));
    defaultLocationdB.append(getenv("USER"));
    defaultLocationdB.append("/.minidlna/cache/");
    ui->lineEdit_4->setText(defaultLocationdB);
    defaultLocationlogs.append(getenv("USER"));
    defaultLocationlogs.append("/.minidlna/");
    ui->lineEdit_5->setText(defaultLocationlogs);
    /*Activem l'autodescobriment per defecte*/
    ui->checkBox->setChecked(true);

    /*Posar els dibuixos estandar de reproducció*/
    ui->pushButton_9->setAutoFillBackground(true);
    ui->pushButton_9->setStyleSheet("background-image:url(:/icons/play-pause.png)");
    ui->pushButton_10->setAutoFillBackground(true);
    ui->pushButton_10->setStyleSheet("background-image:url(:/icons/stop.png)");
    /*Status del servidor a la barra de status*/
    barraStatus();

}
/**************************/
/*Funcions no automàtiques*/
/**************************/

/********************************************/
/*Mostra missatge de confirmació dels canvis*/
/********************************************/

bool MainWindow::confirmaCanvis() {
    QMessageBox confirma;
    confirma.setText(tr("Estas segur que vols aplicar els canvis?<br>'Aplica' nomes es disponible si no fas canvis al directori de registres, si has fet aquest canvi, primer entra el directori actual i atura el servidor, i despres arrenca amb el directori nou"));
    confirma.setWindowTitle("Confirma els canvis");
    confirma.setStandardButtons(QMessageBox::Save | QMessageBox::Cancel);
    confirma.setDefaultButton(QMessageBox::Save);
    confirma.setIcon(QMessageBox::Warning);
    int ret = confirma.exec();
    if (ret == QMessageBox::Save) {
        return true;
    }
    else return false;
}

/**************************/
/*Arrenca el servidor
 *
 *True - Arrenca
 *False - Arrenca amb escaneig de la base de dades
 **/

void MainWindow::arrencaServidor(bool opcio) {
    if (QFile::exists(defaultLocationlogs + "minidlna.conf")) {
        QProcess *p = new QProcess();
        if (opcio) {
            p->start("/bin/bash", QStringList() << "-c" << QString("minidlna -f /home/$USER/.minidlna/minidlna.conf -P /home/$USER/.minidlna/minidlna.pid"));
            p->waitForFinished();
            }
        else {
            p->start("/bin/bash",QStringList() << "-c" << QString("minidlna -f " + defaultLocationlogs +  "minidlna.conf -P " + defaultLocationlogs + "minidlna.pid -R"));
            p->waitForFinished();
        }
        sleep(1);
        if (!QFile::exists(defaultLocationlogs+"minidlna.pid")) {
                QMessageBox::information(this,tr("Error inicialitzacio del servidor"), tr("Assegura't que el directori de treball (logs) sigui el correcte i que existeixi l'arxiu de configuracio amb els parametres necessaris"));
        }
    }
    else {
        QMessageBox::information(this,tr("Error inicialitzacio del servidor"), tr("Assegura't que el directori de treball (logs) sigui el correcte i que existeixi l'arxiu de configuracio amb els parametres necessaris"));
    }
    barraStatus();
}


/*****************************/
/*Connecta a la base de dades*/
/*****************************/

void MainWindow::connectabbdd() {
    QString camibbdd = ui->lineEdit_4->text() + "/files.db";
    /*Comprova que existeix la base de dades*/
    if (QFile::exists(camibbdd)) {
        /*Tipus de base de dades*/
        QSqlDatabase basedades = QSqlDatabase::addDatabase("QSQLITE");
        /*nom de la base de dades*/
        basedades.setDatabaseName(camibbdd);
        /*Obre la base de dades*/
        if (!basedades.open()) {
            QMessageBox::information(this,tr("Error"), tr("Error a l'obertura de la base de dades"));
        }
        /*Apliquem una ordre SQL i la introduim a la vista de tabla*/
        QSqlQueryModel *model = new QSqlQueryModel(this);
        model->setQuery("SELECT [TITLE],[ALBUM],[MIME],[PATH] FROM [DETAILS] WHERE MIME <>''");
        /*Definim els titols dels encapçalaments*/
        model->setHeaderData(0,Qt::Horizontal,QObject::tr("Titol"));
        model->setHeaderData(1,Qt::Horizontal,QObject::tr("Album"));
        model->setHeaderData(2,Qt::Horizontal,QObject::tr("Tipus"));
        model->setHeaderData(3,Qt::Horizontal,QObject::tr("Cami"));
        /*Definim el model i li donem una aparença més estetica*/
        ui->tableView->setModel(model);
        ui->tableView->resizeColumnsToContents();
        ui->tableView->setAlternatingRowColors(true);
    }
    /*Si no existeix al camí per defecte, demana la introducció del camí correcte*/
    else {
        QMessageBox::information(this,tr("Informe error"), tr("La base de dades no esta al directori habitual, entra el cami correcte a la pestanya de configuracio"));
        return;
    }

 }

/****************************************/
/*Escriure parametres a l'arxiu temporal*/
/****************************************/

bool MainWindow::escriureParametres(QString descripcio, QString parametre)
{
    //Directori de treball

    QDir::setCurrent(ui->lineEdit_5->text());

    //Obre l'arxiu
    QFile nom("nou.txt");
    if (!nom.open(QFile::Append | QFile::Text)) {
            QMessageBox::information(this,tr("Error"), tr("Hi han problemes amb els permisos d'usuari"));
            return false;
    }
    else {
        //Escriu a l'arxiu
        QTextStream out(&nom);
        out << descripcio << parametre << "\n";
        //tanca l'arxiu
        nom.flush();
        nom.close();
        return true;
    }
}

/*Fer apareixer l'estatus del servidor a la barra d'estatus*/
void MainWindow::barraStatus()
{
    sleep(1);
    if (QFile::exists(defaultLocationlogs+"minidlna.pid")) {
        ui->statusBar->showMessage(tr("Servidor funcionant"),0);
    }
    else {
        ui->statusBar->showMessage(tr("Servidor aturat"),0);
    }
}

/*Fi de funcions no automatiques*/

MainWindow::~MainWindow()
{
    delete ui;
}
/*******************/
/*Arrencar Servidor*/
/*******************/
void MainWindow::on_pushButton_clicked()
{
    /*Cridem a la funció d'arrencar el servidor amb l'opció de no escanejar de nou la base de dades*/
    arrencaServidor(true);
}

/****************************/
/*Aplica nous parametres    */
/****************************/

void MainWindow::on_pushButton_2_clicked()
{
    if (confirmaCanvis()) {
    //Directori de treball
    QDir::setCurrent(ui->lineEdit_5->text());

    /****************************/
    /*Escriu el paràmetre log_dir*/
    /****************************/
    QString checkDir = ui->lineEdit_5->text();
    if (!QDir(checkDir).exists()) {
        QDir dir(QDir::rootPath());
        if (!dir.mkpath(checkDir)) {
            QMessageBox::information(this,tr("Error creació directori registre"), tr("Directori Registres no creat, mira altre cop que els noms dels directoris son correctes i existeixen i tens permis per escriure-hi"));
            QFile::remove("nou.txt");
            return;
        }
    }
    /*El pasem com a parametre*/
    if (!(escriureParametres("log_dir=", ui->lineEdit_5->text()))) {
        QMessageBox::information(this,tr("Error"), tr("Hi han problemes d'escriptura dels parametres"));
        return;
    }

    /***************************************************/
    /*Escriu el paràmetre PORT si és un numero correcte*/
    /***************************************************/
    int port = ui->lineEdit->text().toInt();
    if (0 < port && port < 65535) {
        if (!(escriureParametres("port=", QString::number(port)))) {
            QMessageBox::information(this,tr("Error"), tr("Hi han problemes d'escriptura dels parametres"));
            return;
        }
    }
    /*Si no és un numero correcte trenca la funció i borra l'arxiu temporal després de mostrar un missatge de com s'ha d'escriure*/
    else {
        QMessageBox::information(this,tr("Comprova-ho altre cop, si us plau"), tr("El numero de port ha d'estar entre 0 - 65535"));
        QFile::remove("nou.txt");
        return;
    }

    /******************************************************/
    /*Escriu el paràmetre network_interface si és emplenat*/
    /******************************************************/

    if (ui->lineEdit_2->text()!="") {
        if (!(escriureParametres("network_interface=", ui->lineEdit_2->text()))) {
            QMessageBox::information(this,tr("Error"), tr("Hi han problemes d'escriptura dels parametres"));
            return;
        }
    }

    /***********************************/
    /*Escriu el paràmetre friendly_name*/
    /***********************************/

    if (!(escriureParametres("friendly_name=", ui->lineEdit_3->text()))) {
        QMessageBox::information(this,tr("Error"), tr("Hi han problemes d'escriptura dels parametres"));
        return;
    }

    /****************************/
    /*Escriu el paràmetre db_dir*/
    /****************************/
    checkDir = ui->lineEdit_4->text();
    /*Si no existeix, es crea*/
    if (!QDir(checkDir).exists()) {
        QDir dir(QDir::rootPath());
        if (!dir.mkpath(checkDir)) {
            QMessageBox::information(this,tr("Error creació directori base de dades"), tr("Directori Base de Dades no creat, mira altre cop que els noms dels directoris son correctes i existeixen i tens permis per escriure-hi"));
            QFile::remove("nou.txt");
            return;
        }
    }
    /*El pasem com a parametre*/
    if (!(escriureParametres("db_dir=", ui->lineEdit_4->text()))) {
        QMessageBox::information(this,tr("Error"), tr("Hi han problemes d'escriptura dels parametres"));
        return;
    }


    /************************************/
    /*Escriu el paràmetre root_container*/
    /************************************/
    QString auxString = ui->comboBox->itemText(ui->comboBox->currentIndex());

    /*Canvia el tipus per la seva identitat*/
    if (auxString=="Navega") { auxString ="B";}
    if (auxString=="Imatges") { auxString ="P";}
    if (auxString=="Audio") { auxString ="M";}
    if (auxString=="Video") { auxString ="V";}
    if (auxString=="Estandard") { auxString =".";}
    if (!(escriureParametres("root_container=", auxString))) {
        QMessageBox::information(this,tr("Error"), tr("Hi han problemes d'escriptura dels parametres"));
        return;
    }

    /*******************************/
    /*Escriu el paràmetre media_dir*/
    /*******************************/
    /*Per a totes les entrades, les entra independenment*/
    /*Comptador d'entrades*/
    int max= ui->listWidget->count();

    /*Si no s'ha entrat cap directori, avisa i surt*/
    if (max==0) {
        QMessageBox::information(this,tr("Error directoris multimedia"), tr("Has d'entrar almenys un directori"));
        QFile::remove("nou.txt");
        return;
    }
    /*Entra els directoris*/
    else {
        for (int i=0;i<max ;i++) {
            auxString = ui->listWidget->item(i)->text();
            if (!(escriureParametres("media_dir=", auxString))) {
                QMessageBox::information(this,tr("Error"), tr("Hi han problemes d'escriptura dels parametres"));
                return;
            }
        }
    }

    /*******************************/
    /*Escriu el paràmetre inotify***/
    /*******************************/
    if (ui->checkBox->isChecked()) {
        if (!(escriureParametres("inotify=","yes"))) {
            QMessageBox::information(this,tr("Error"), tr("Hi han problemes d'escriptura dels paraametres"));
            return;
        }
    }
    else {
        if (!(escriureParametres("inotify=","no"))) {
            QMessageBox::information(this,tr("Error"), tr("Hi han problemes d'escriptura dels parametres"));
            return;
        }
    }

    /*Escribim la resta de l'arxiu de configuració*/
    if (!(escriureParametres("# --Plantilla--\n", PLANTILLA))) {
        QMessageBox::information(this,tr("Error"), tr("Hi han problemes d'escriptura dels parametres"));
    }

    /**************************************/
    /*Esborra la copia de seguretat antiga*/
    /**************************************/

    /*Si existeix esborra - Si no esborra correctament, llença un missatge*/
    if (QFile::exists("minidlna_old.conf")) {
        if (!QFile::remove("minidlna_old.conf")) {
            QMessageBox::information(this,tr("Informe error"), tr("No esborrat minidlna_old.conf correctament"));
        }
    }
   
    /********************************************************************/
    /*Creació de la còpia de seguretat de l'arxiu de configuració actual*/
    /********************************************************************/

    /*Passar la ubicació dels logs i la configuració al directori especificat*/
    defaultLocationlogs = ui->lineEdit_5->text();

    /*Si existeix còpia (renombra) al directori nou - Si no còpia correctament, llença un missatge*/
    if (QFile::exists("minidlna.conf")) {
        if (!QFile::rename("minidlna.conf", defaultLocationlogs + "/minidlna_old.conf")) {
            QMessageBox::information(this,tr("Error backup"), tr("Backup no fet correctament, assegura't que els noms dels directoris son correctes i existeixen i tens permis per escriure-hi"));
            return;
        }
    }
    
    /***********************/
    /*Renombrem l'arxiu nou*/
    /***********************/
    if (!QFile::rename("nou.txt", defaultLocationlogs + "/minidlna.conf")) {
        QMessageBox::information(this,"Error", "Ops, assegura't que els noms dels directoris son correctes i existeixen i tens permis per escriure-hi!");
        QFile::remove("nou.txt");
    }

    /**************************************************************************************************/
    /*Mata el procés existent, si existeix, del minidlna i el tornem a engegar amb els parametres nous*/
    /**************************************************************************************************/
    /*Crida a la funció del botó d'aturar el procés*/
    on_pushButton_3_clicked();
    /*Encenem el servidor amb escaneig de la base de dades*/
    arrencaServidor(false);
    }
    else return;
}

/*******************/
/*Atura el servidor*/
/*******************/

void MainWindow::on_pushButton_3_clicked() {
    /*Definim el camí cap a l'arxiu que conté el PID del miniDLNA"*/
    QString camiaPID = ui->lineEdit_5->text() + "minidlna.pid";
    /*Si l'arxiu existeix, aturem el procés*/
    if (QFile::exists(camiaPID)) {
        /*Definim l'arxiu sobre el qual operar*/
        QFile arxiuPID(camiaPID);
        /*Obrim l'arxiu a prova d'errors*/
        if (!arxiuPID.open(QIODevice::ReadOnly | QIODevice::Text)) {
            QMessageBox::information(this,"Error", tr("Arxiu PID no obert"));}
            /*LLegim la primera i unica linea que conte el PID*/
            QTextStream in(&arxiuPID);
            QString nrpid = in.readLine();
            /*Definim un process intern per a executar una ordre*/
            QProcess *p = new QProcess();
            /*Executem l'ordre de matar el procés del servidor: kill pid "nº de pid"*/
            p->start("/bin/bash",QStringList() << "-c" << QString("kill pid "+ nrpid));
            p->waitForFinished();
            /*Mostrem a la barra de status que hem aturat*/
            barraStatus();
    }
}

/*************************/
/*Directori base de dades*/
/*************************/

void MainWindow::on_pushButton_4_clicked()
{
    //Selecciona el directori
    QString dir;
    dir = QFileDialog::getExistingDirectory(this,tr("Selecciona directori"), defaultLocationdB, QFileDialog::ShowDirsOnly | QFileDialog::DontResolveSymlinks);
    //Si no es cancela, entra el directori, si no no fa res
    if (dir != "") {
        ui->lineEdit_4->setText(dir);
    }
}

/*******************/
/*Directori de logs*/
/*******************/

void MainWindow::on_pushButton_5_clicked()
{
    //Selecciona el directori
    QString dir;
    dir = QFileDialog::getExistingDirectory(this,tr("Selecciona directori"), defaultLocationlogs, QFileDialog::ShowDirsOnly | QFileDialog::DontResolveSymlinks);
    //Si no es cancela, entra el directori, si no no fa res
    if (dir != "") {
        ui->lineEdit_5->setText(dir);
    }
}

/***********************************/
/*Directoris multimedia a la llista*/
/***********************************/

void MainWindow::on_pushButton_6_clicked()
{
    //Reformata el tipus
    QString auxString = ui->comboBox_2->itemText(ui->comboBox_2->currentIndex());
    if (auxString=="Imatges") { auxString ="P,";}
    if (auxString=="Audio") { auxString ="A,";}
    if (auxString=="Video") { auxString ="V,";}
    if (auxString=="General") { auxString ="";}
    //Selecciona directori
    QString dir;
    dir = QFileDialog::getExistingDirectory(this,tr("Selecciona directori"), "/home/", QFileDialog::ShowDirsOnly | QFileDialog::DontResolveSymlinks);
    //Inserta directori
    if (dir != "") {
        ui->listWidget->addItem(auxString+dir);
    }
}

/****************************************/
/**Visualitza la base de dades***********/
/****************************************/

void MainWindow::on_pushButton_7_clicked()
{
    connectabbdd();
}

/****************************************************************/
/*Reprodueix l'arxiu a sobre del que es fa doble-click***********/
/****************************************************************/

void MainWindow::on_tableView_doubleClicked(const QModelIndex &index)
{
    /*Si està reproduint primer para la reproducció actual*/
    if (ui->videoPlayer->isPlaying()) {
            ui->videoPlayer->stop();
    }
    /*Guardem el nuero de fila*/
    int fila = index.row();
    /*Mitjançant la classe QVariant, que es com un container de tipus, guardem el camí*/
    QVariant camiaMVariant = ui->tableView->model()->data(ui->tableView->model()->index(fila,3));
    /*Converti el camí a cadena*/
    QString camiaM = camiaMVariant.toString();
    /*Carreguem, reproduim i enllacem el control de progrès*/
    ui->videoPlayer->load(camiaM);
    ui->videoPlayer->play();
    ui->seekSlider->setMediaObject(ui->videoPlayer->mediaObject());
}

/************/
/*Botó pausa*/
/************/

void MainWindow::on_pushButton_9_clicked()
{
    if (ui->videoPlayer->isPlaying()) {
        ui->videoPlayer->pause();
    }
    else {
        ui->videoPlayer->play();
        ui->seekSlider->setMediaObject(ui->videoPlayer->mediaObject());
    }
}

/***********/
/*Botó stop*/
/***********/

void MainWindow::on_pushButton_10_clicked()
{
    ui->videoPlayer->stop();
}

/*********************************************/
/*Funcions del menú que són iguals als botons*/
/*********************************************/

void MainWindow::on_actionArrenca_triggered()
{
    on_pushButton_clicked();
}


void MainWindow::on_actionAplica_triggered()
{
    on_pushButton_2_clicked();
}

void MainWindow::on_actionAtura_triggered()
{
    on_pushButton_3_clicked();
}

void MainWindow::on_actionVisualitza_triggered()
{
    on_pushButton_7_clicked();
}

/*Actualitza base de dades*/
void MainWindow::on_pushButton_8_clicked()
{
    /*Esborra la taula*/
    ui->tableView->reset();
    /*Aplica canvis*/
    on_pushButton_2_clicked();
    /*Mostra de nou la biblioteca*/
    on_pushButton_7_clicked();
}

void MainWindow::on_actionActualitza_triggered()
{
    on_pushButton_8_clicked();
}



    
    
bool MainWindow::llegeixArxiuConf(QString arxiuConf) {
      QFile file(arxiuConf);
      if(!file.open(QIODevice::ReadOnly)) {
          QMessageBox::information(0, "error", file.errorString());
          return false;
      }
      QTextStream in(&file);
      while(!in.atEnd()) {
          QString line = in.readLine();
          processaLineaConf(line);
      }
      return true;
}
    
void MainWindow::processaLineaConf(QString line) {
      if (line.startsWith("#")) {return;}

      if (line.startsWith("port=")) {
          line.replace("port=","");
          ui->lineEdit->setText(line);
          return;
      }
      if (line.startsWith("network_interface=")) {
          line.replace("network_interface=","");
          ui->lineEdit_2->setText(line);
          return;
      }
      if (line.startsWith("friendly_name=")) {
          line.replace("friendly_name=","");
          ui->lineEdit_3->setText(line);
          return;
      }
      if (line.startsWith("db_dir=")) {
          line.replace("db_dir=","");
          ui->lineEdit_4->setText(line);
          return;
      }
      if (line.startsWith("log_dir=")) {
          line.replace("log_dir=","");
          ui->lineEdit_5->setText(line);
          return;
      }
      if (line.startsWith("inotify=yes")) {
          ui->checkBox->setChecked(true);
          return;
      }
      if (line.startsWith("inotify=no")) {
          ui->checkBox->setChecked(false);
          return;
      }
      if (line.startsWith("media_dir=")) {
          line.replace("media_dir=","");
          ui->listWidget->addItem(line);
          return;
      }
      if (line.startsWith("root_container=")) {
          line.replace("root_container=","");

          if (line=="B") {
              ui->comboBox->setCurrentIndex(0);
              return;
          }
          if (line=="P") {
              ui->comboBox->setCurrentIndex(1);
              return;
          }
          if (line=="M") {
              ui->comboBox->setCurrentIndex(2);
              return;
          }
          if (line=="V") {
              ui->comboBox->setCurrentIndex(3);
              return;
          }
          if (line==".") {
              ui->comboBox->setCurrentIndex(4);
              return;
          }
          return;
      }

}
    
void MainWindow::on_actionObre_triggered() {
    //Selecciona el fitxer
    QString arxiuConf;
    arxiuConf = QFileDialog::getOpenFileName(this,tr("Selecciona fitxer"), defaultLocationlogs, tr("Arxius configuracio (*.conf)"));
    //Si no es cancela, entra el fitxer, si no no fa res
    if (arxiuConf != "") {
        if (llegeixArxiuConf(arxiuConf)) {
            QMessageBox::information(this,tr("Exit"), tr("L'arxiu s'ha processat amb exit, comprova els resultats"));
        }
        else {
            QMessageBox::information(this,tr("Fracas"), tr("Hi ha hagut algun problema a l'importar la configuracio, comprova que el fitxer entrat sigui valid"));
        }
    }
}

void MainWindow::on_pushButton_11_clicked()
{
    int fila = seleccionat.row();
    QVariant camiaMVariant = ui->tableView->model()->data(ui->tableView->model()->index(fila,3));
    QString camiaM = camiaMVariant.toString();
    QSqlQuery qry;
    qry.prepare("DELETE FROM [DETAILS] WHERE [PATH]=?");
    qry.addBindValue(camiaM);
    if (!qry.exec()) {
        QMessageBox::information(this,tr("Error"), qry.lastError().databaseText());
    }
    /*Esborra la taula*/
    ui->tableView->reset();
    /*Mostra de nou la biblioteca*/
    QSqlQueryModel *model = new QSqlQueryModel(this);
    model->setQuery("SELECT [TITLE],[ALBUM],[MIME],[PATH] FROM [DETAILS] WHERE MIME <>''");
    ui->tableView->setModel(model);
    ui->tableView->resizeColumnsToContents();
}

void MainWindow::on_tableView_clicked(const QModelIndex &index)
{
    seleccionat = index;

}

void MainWindow::on_listWidget_clicked(const QModelIndex &index)
{
    seleccionat = index;
}

void MainWindow::on_pushButton_12_clicked()
{
   int fila = seleccionat.row();
   ui->listWidget->takeItem(fila);

}

void MainWindow::on_actionQuant_a_triggered()
{
    QMessageBox quantA;
    quantA.setText(QString::fromUtf8("<h1>MiniDLNA Tweaker 1.0</h1><br>Pendent de decidir llicència<br>Treball final de Carrera<br>Enginyeria Tècnica en Telecomunicacions<br>Especialitat en Telemàtica<br><h2>Jordi Martinez Lloveras</h2><br>Juny 2013"));
    quantA.setWindowTitle("Quant a");
    quantA.setIconPixmap(QPixmap(":/icons/icon.png"));
    quantA.exec();
}

void MainWindow::on_actionContinguts_triggered()
{
    QMessageBox continguts;
    QSpacerItem* horizontalSpacer = new QSpacerItem(800, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);
    continguts.setText(QString::fromUtf8("<h1>Minidlna_tweak 1.0</h1>"
                                         "<h2>Aplicació per a configurar el servidor MiniDlna</h2>"
                                         "<h3>Preguntes més freqüents</h3>"
                                         "<dl>"
                                             "<dt>Què és MiniDlna_tweak?</dt>"
                                             "<dd>MiniDLna_tweak és una aplicació per a configurar el servidor DLNA per a Linux MiniDlna</dd>"
                                             "<br>"
                                             "<dt>Per a quines distribucions funciona?</dt>"
                                             "<dd>L'aplicació ha de funcionar a totes les distribucions de Linux més conegudes, està provada cent per cent a dues distribucions:Ubuntu i els seus derivats i PCLinuxOS</dd>"
                                         "<br>"
                                             "<dt>Quines dependències té?</dt>"
                                             "<dd><p>L'aplicació està feta amb les llibreries Qt, per tant depèn de les llibreries Qt i per suposat del servidor multimèdia MiniDLNA. També depèn de l'entorn multimèdia de les llibreries Qt, el Phonon.</p>"
                                                 "<p>Les dependències es poden instal·lar a l'Ubuntu (12.04) amb les ordres:</p>"
                                                 "<ul>sudo apt-get install minidlna phonon libphonon4 libegl1-mesa-lts-quantal</ul>"
                                                 "<p>Per a un correcte funcionament del servidor MiniDLNA en mode usuari, no procés del sistema, cal executar aquestes ordres:</p>"
                                                 "<ul>sudo service minidlna stop</ul>"
                                                 "<ul>sudo update-rc.d minidlna disable</ul></dd>"
                                                 "<br>"
                                             "<dt>Qué es pot fer amb el MiniDlna_Tweak?</dt>"
                                             "<dd>Amb aquesta aplicació l'usuari pot fer tres grans coses:"
                                             "<ul>Controlar el servidor: Engegar, aturar, i aplicar els canvis</ul>"
                                             "<ul>Fer canvis als paràmetres del fitxer de configuració del MiniDlna</ul>"
                                             "<ul>Visualitzar la llista d'arxius que hi han a la biblioteca multimèdia del servidor i previsualitzar-los </ul></dd>"
                                             "<br>"
                                             "<dt>És segur fer canvis en aquests paràmetres?</dt>"
                                             "<dd>Els paràmetres que venen per defecte amb l'aplicació son totalment segurs, ara be, si es volen canviar millor no sortir-se pels directoris de configuració de l'àrea de l'usuari. De totes formes, l'aplicació avisarà si en el directori escollit es tenen els permisos necessaris per a escriure. Amb el numero de port i el nom de la interfície de xarxa si que ha d'anar amb compte, doncs el servidor podria no funcionar correctament i l'aplicació no detectar el motiu. Si te dubtes, 'ha de deixar com està per defecte que funcionarà en la immensa majoria dels casos.</dd>"
                                         "</dl>"));
    continguts.setWindowTitle("Continguts");
    continguts.setIconPixmap(QPixmap(":/icons/icon.png"));
    QGridLayout* layout = (QGridLayout*)continguts.layout();
    layout->addItem(horizontalSpacer, layout->rowCount(), 0, 1, layout->columnCount());
    continguts.exec();
}
