#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QMainWindow>
#include <QFileDialog>
#include <QPushButton>
#include <QString>
#include <QListView>
#include <QDesktopServices>
#include <stdlib.h>
#include <QProcess>
#include <QDebug>
#include <QFile>
#include <QTextStream>
#include <QMessageBox>
#include <unistd.h>
#include <QtSql>

namespace Ui {
class MainWindow;
}

//! Clase Mainwindow.
/*!
	És la clase per a definir les funcions generades per la interacció de la finestra
	És declara filla de la classe QMainWindow del Qt, que ja té les funcions estandards 
	d'interacció.
*/

class MainWindow : public QMainWindow
{
    Q_OBJECT
    
public:
	//! Constructor.
	/*!
	*/
    explicit MainWindow(QWidget *parent = 0);
	//! Destructor.
	/*!
	*/
    ~MainWindow();
	

private slots:

    //!Funció per a que l'usuari confirmi que vol canviar els paràmetres
    /*!
     * \brief confirmaCanvis Mostra un  missatge de dialeg de confirmació per a confirma els canvia
     * \return true si pitja OK, false si pitja cancela
     */
    bool confirmaCanvis();

    //! Funcio per llegir un arxiu i importar els paràmetres
    /*!
     * \brief llegeixArxiuConf Llegeix un arxiu linia per linia i importa els parametres gràcies a la formatació dels arxius de configuració
     * \param arxiuConf L'arxiu d'importació
     * \return true si ha anat be, false si hi ha hagut algun error
     */
    bool llegeixArxiuConf(QString arxiuConf);

    //! Funcio per a processar cada linia de l'arxiu de configuració obert
    /*!
     * \brief processaLineaConf Processa cada linia de l'arxiu
     * \param line La linia oberta per a cada processament
     */
    void processaLineaConf(QString line);

    //! Funció per arrencar el servidor
    /*!
     * \brief arrencaServidor Arrenca el servidor depenent del parametre opcio escanejant o no la Base de dades
     * \param opcio Si és true només arrenca el servidor, si és false, escaneja la base de dades
     */
    void arrencaServidor(bool opcio);


    //! Funció per a connectar amb la base de dades i visualitzarla.
	/*!
	 * \brief	Agafa la posició per defecte de la base de dades i la intenta visualitzar
		a la vista de taula, si no ho aconsegueix, demana la explicitació de la
		ruta a l'entrada de text de la ruta a la base de dades
	*/	
    void connectabbdd();
	//! Funció per a visualitzar l'estatus del servidor a la barra inferior d'estat.
	/*!
	 * \brief	Comprova que existeixi l'arxiu amb el PID que es genera a cada arrencada dels servidor.
		Si existeix, el servidor funciona, si no existeix, no funciona
	*/	
    void barraStatus();
    //! Funció per a escriure els paràmetres a l'arxiu intermig.
    /*!
        \param descripcio Un QString(String en format Qt) amb la descripció del paràmetre
        \param parametre  Un QString(String en format Qt) amb el parametre entrat o per defecte
    */
    bool escriureParametres(QString descripcio, QString parametre);
    
	//! Arrenca el servidor.
	/*!
	 * \brief	Si falla, mostra un pop-up amb instruccions
	*/
    void on_pushButton_clicked();

	//! Aplica els nous paràmetres.
	/*!
	 * \brief	Comprova que els parametres siguin correctes, fa un backup de la configuració existent,
		desa els parametres a l'arxiu de configuració, atura i re-arrenca el servidor
		amb la configuració nova escanejant la biblioteca.
		Si falla, mostra un pop-up amb instruccions
	*/
    void on_pushButton_2_clicked();

	//! Atura el servidor.
	/*!
	 * \brief	Si falla, mostra un pop-up amb instruccions
	*/
    void on_pushButton_3_clicked();

	//! Selecciona el directori de la base de dades.
	/*!
	 * \brief	Mostra el menu contextual per a seleccionar un directori
	*/
    void on_pushButton_4_clicked();

	//! Selecciona el directori dels arxius de registre i configuració.
	/*!
	 * \brief	Mostra el menu contextual per a seleccionar un directori
	*/
    void on_pushButton_5_clicked();

	//! Selecciona el directori que volem afegir a la base de dades.
	/*!
		Mostra el menu contextual per a seleccionar un directori, i l'afegeix 
		a la vista de la llista que s'afegirà al fitxer de configuració del servidor
	*/
    void on_pushButton_6_clicked();
	
	//! Visualitza la base de dades a la vista de taula.
	/*!
	 * \brief	Redirecciona cap a la funció connectabbdd
	*/
    void on_pushButton_7_clicked();
	
	//! Reprodueix l'arxiu sobre el que es fa dobla clic.
	/*!
	 * \brief	Si es fa doble clic sobre la fila de l'arxiu, el reprodueix o atura la reproducció
		en curs. Funcionalitat estranya??
	*/
    void on_tableView_doubleClicked(const QModelIndex &index);

	//! Pausa la reproducció.
	/*!
	 * \brief	Si està reproduint, pausa, si està en pausa, continua la reproducció
	*/
    void on_pushButton_9_clicked();

	//! Atura la reproducció.
	/*!
	 * \brief	Si està reproduint, atura la reproducció i descarrega l'arxiu de la memoria
	*/
    void on_pushButton_10_clicked();

	//! Barra de Menú - Arrenca el servidor
	/*!
	 * \brief	Redirecciona cap a la funció del botó d'arrencar
	*/
    void on_actionArrenca_triggered();

	//! Barra de Menú - Aplica la configuració nova.
	/*!
	 * \brief	Redirecciona cap a la funció del botó d'aplicar
	*/
    void on_actionAplica_triggered();
	
	//! Barra de Menú - Atura el servidor.
	/*!
	 * \brief	Redirecciona cap a la funció del botó d'aturar
	*/
    void on_actionAtura_triggered();

	//! Barra de Menú - Visualitza .
	/*!
	 * \brief	Redirecciona cap a la funció del botó de Visualitzar
	*/
    void on_actionVisualitza_triggered();
	
	//! Actualitza la vista de la base de dades.
	/*!
	 * \brief	Fa un reset de la taula
		Redirecciona cap a aplicar nous canvis per si s'han actualitzat els directoris
		Torna a mostrar la base de dades
	*/
    void on_pushButton_8_clicked();
	
	//! Barra de Menú - Atura el servidor.
	/*!
	 * \brief	Redirecciona cap a la funció del botó d'actualitzar
	*/
    void on_actionActualitza_triggered();

    //! Barra de Menú - Obre un fitxer de configuració.
    /*!
     * \brief   Obre un fitxer especificat i importa els paràmetres
    */
    void on_actionObre_triggered();
	
	//! Funció per a copiar l'objecte seleccionat
    /*!
     * \brief   Funció que copia l'objecte seleccionat a la vista de taula a una variable global index per a poder-la processa a altres funcions
    */
    void on_tableView_clicked(const QModelIndex &index);

	//! Barra de Menú - Obre un fitxer de configuració.
    /*!
     * \brief   Obre un fitxer especificat i importa els paràmetres
    */
    void on_pushButton_11_clicked();

    //! Funció per a copiar l'objecte seleccionat
    /*!
     * \brief   Funció que copia l'objecte seleccionat a la vista de llista a una variable global index per a poder-la processa a altres funcions
    */
    void on_listWidget_clicked(const QModelIndex &index);

    //! Funció que esborra l'objecte seleccionat de la llista
    /*!
     * \brief  Funció del botó Esborra directori que esborra el directori de la vista de llista
    */
    void on_pushButton_12_clicked();

    //! Barra de Menú - Ajuda->Quant a.
    /*!
     * \brief  Treu un pop-up amb la informació global de l'aplicació
    */
    void on_actionQuant_a_triggered();
    //! Barra de Menú - Ajuda->Continguts
    /*!
     * \brief  Treu un pop-up amb una petita ajuda
    */
    void on_actionContinguts_triggered();

private:
    Ui::MainWindow *ui;
};

#endif // MAINWINDOW_H
